@@ -13,7 +13,7 @@ use Readonly;
 Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 
-our $VERSION = 0.28;
+our $VERSION = 0.29;
 
 # Process error.
 sub err {
@@ -56,6 +56,14 @@ Error::Pure::ANSIColor::AllError - Error::Pure module with full backtrace.
 
  err "This is a fatal error.", "name", "value";
 
+ # __or__
+
+ use Error::Pure qw(err);
+
+ $ENV{'ERROR_PURE_TYPE'} = 'ANSIColor::AllError';
+
+ err "This is a fatal error.", "name", "value";
+
 =head1 SUBROUTINES
 
 =head2 B<err>
@@ -66,17 +74,16 @@ Process error with messages (error, error_key/value pairs).
 
 =head1 EXAMPLE
 
+=for comment filename=err_via_ansicolor_all_error.pl
+
  use strict;
  use warnings;
 
  use Error::Pure::ANSIColor::AllError qw(err);
 
- print "1\n";
  err "This is a fatal error.", "name", "value";
- print "2\n";
 
  # Output:
- # 1
  # ERROR: This is a fatal error.
  # name: value
  # main  err  ./script.pl  12
@@ -117,6 +124,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.28
+0.29
 
 =cut
