@@ -9,7 +9,7 @@ use Error::Pure::Utils qw(err_helper);
 use List::Util qw(none);
 use Readonly;
 
-our $VERSION = 0.28;
+our $VERSION = 0.29;
 
 # Constants.
 Readonly::Array our @EXPORT_OK => qw(err);
@@ -57,6 +57,14 @@ Error::Pure::ANSIColor::Die - Error::Pure module with classic die.
 
  err 'This is a fatal error', 'name', 'value';
 
+ # __or__
+
+ use Error::Pure qw(err);
+
+ $ENV{'ERROR_PURE_TYPE'} = 'ANSIColor::Die';
+
+ err "This is a fatal error.", "name", "value";
+
 =head1 SUBROUTINES
 
 =head2 B<err>
@@ -67,6 +75,8 @@ Process error with messages (error, error_key/value pairs).
 
 =head1 EXAMPLE1
 
+=for comment filename=err_via_ansicolor_die.pl
+
  use strict;
  use warnings;
 
@@ -76,10 +86,12 @@ Process error with messages (error, error_key/value pairs).
  err '1';
 
  # Output:
- # 1 at example1.pl line 9.
+ # 1 at ../err_via_ansicolor_die.pl line 9.
 
 =head1 EXAMPLE2
 
+=for comment filename=err_via_ansicolor_die_with_params.pl
+
  use strict;
  use warnings;
 
@@ -89,10 +101,12 @@ Process error with messages (error, error_key/value pairs).
  err '1', '2', '3';
 
  # Output:
- # 1 at example2.pl line 9.
+ # 123 at ../err_via_ansicolor_die_with_params.pl line 9.
 
 =head1 EXAMPLE3
 
+=for comment filename=err_via_ansicolor_die_with_params_in_eval_and_dump.pl
+
  use strict;
  use warnings;
 
@@ -104,13 +118,13 @@ Process error with messages (error, error_key/value pairs).
  eval { err '1', '2', '3'; };
 
  # Error structure.
- my $err_ar = err_get();
+ my @err = err_get();
 
  # Dump.
  my $dump = Dumpvalue->new;
- $dump->dumpValues($err_ar);
+ $dump->dumpValues(@err);
 
- # In $err_ar:
+ # In @err:
  # [
  #         {
  #                 'msg' => [
@@ -123,14 +137,14 @@ Process error with messages (error, error_key/value pairs).
  #                                 'args' => '(1)',
  #                                 'class' => 'main',
  #                                 'line' => '9',
- #                                 'prog' => 'script.pl',
+ #                                 'prog' => 'err_via_ansicolor_die_with_params_in_eval_and_dump.pl',
  #                                 'sub' => 'err',
  #                         },
  #                         {
  #                                 'args' => '',
  #                                 'class' => 'main',
  #                                 'line' => '9',
- #                                 'prog' => 'script.pl',
+ #                                 'prog' => 'err_via_ansicolor_die_with_params_in_eval_and_dump.pl',
  #                                 'sub' => 'eval {...}',
  #                         },
  #                 ],
@@ -173,6 +187,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.28
+0.29
 
 =cut
