@@ -13,7 +13,7 @@ use Readonly;
 Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 
-our $VERSION = 0.28;
+our $VERSION = 0.29;
 
 # Process error.
 sub err {
@@ -57,6 +57,14 @@ with informations.
 
  err "This is a fatal error.", "name", "value";
 
+ # __or__
+
+ use Error::Pure qw(err);
+
+ $ENV{'ERROR_PURE_TYPE'} = 'ANSIColor::ErrorList';
+
+ err "This is a fatal error.", "name", "value";
+
 =head1 SUBROUTINES
 
 =head2 B<err>
@@ -67,6 +75,8 @@ Process error with messages (error, error_key/value pairs).
 
 =head1 EXAMPLE1
 
+=for comment filename=err_via_ansicolor_error_list.pl
+
  use strict;
  use warnings;
 
@@ -80,6 +90,8 @@ Process error with messages (error, error_key/value pairs).
 
 =head1 EXAMPLE2
 
+=for comment filename=err_via_ansicolor_error_list_with_params.pl
+
  use strict;
  use warnings;
 
@@ -93,6 +105,8 @@ Process error with messages (error, error_key/value pairs).
 
 =head1 EXAMPLE3
 
+=for comment filename=err_via_ansicolor_error_list_in_eval_plus_err.pl
+
  use strict;
  use warnings;
 
@@ -145,6 +159,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.28
+0.29
 
 =cut
