@@ -14,7 +14,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EMPTY_STR => q{};
 Readonly::Scalar my $EVAL => 'eval {...}';
 
-our $VERSION = 0.28;
+our $VERSION = 0.29;
 
 # Process error.
 sub err {
@@ -57,6 +57,14 @@ Error::Pure::ANSIColor::PrintVar - Error::Pure module for simple error print wit
 
  err 'This is a fatal error', 'name', 'value';
 
+ # __or__
+
+ use Error::Pure qw(err);
+
+ $ENV{'ERROR_PURE_TYPE'} = 'ANSIColor::PrintVar';
+
+ err "This is a fatal error.", "name", "value";
+
 =head1 SUBROUTINES
 
 =head2 C<err>
@@ -67,6 +75,8 @@ Process error with messages (error, error_key/value pairs).
 
 =head1 EXAMPLE1
 
+=for comment filename=err_via_ansicolor_print_var.pl
+
  use strict;
  use warnings;
 
@@ -80,6 +90,8 @@ Process error with messages (error, error_key/value pairs).
 
 =head1 EXAMPLE2
 
+=for comment filename=err_via_ansicolor_print_var_with_params.pl
+
  use strict;
  use warnings;
 
@@ -94,6 +106,8 @@ Process error with messages (error, error_key/value pairs).
 
 =head1 EXAMPLE3
 
+=for comment filename=err_via_ansicolor_print_var_with_params_from_module.pl
+
  package Example3;
 
  use strict;
@@ -154,6 +168,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.28
+0.29
 
 =cut
